# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.cloud.discoveryengine import gapic_version as package_version

__version__ = package_version.__version__


from google.cloud.discoveryengine_v1beta.services.document_service.async_client import (
    DocumentServiceAsyncClient,
)
from google.cloud.discoveryengine_v1beta.services.document_service.client import (
    DocumentServiceClient,
)
from google.cloud.discoveryengine_v1beta.services.recommendation_service.async_client import (
    RecommendationServiceAsyncClient,
)
from google.cloud.discoveryengine_v1beta.services.recommendation_service.client import (
    RecommendationServiceClient,
)
from google.cloud.discoveryengine_v1beta.services.user_event_service.async_client import (
    UserEventServiceAsyncClient,
)
from google.cloud.discoveryengine_v1beta.services.user_event_service.client import (
    UserEventServiceClient,
)
from google.cloud.discoveryengine_v1beta.types.common import CustomAttribute, UserInfo
from google.cloud.discoveryengine_v1beta.types.document import Document
from google.cloud.discoveryengine_v1beta.types.document_service import (
    CreateDocumentRequest,
    DeleteDocumentRequest,
    GetDocumentRequest,
    ListDocumentsRequest,
    ListDocumentsResponse,
    UpdateDocumentRequest,
)
from google.cloud.discoveryengine_v1beta.types.import_config import (
    BigQuerySource,
    GcsSource,
    ImportDocumentsMetadata,
    ImportDocumentsRequest,
    ImportDocumentsResponse,
    ImportErrorConfig,
    ImportUserEventsMetadata,
    ImportUserEventsRequest,
    ImportUserEventsResponse,
)
from google.cloud.discoveryengine_v1beta.types.recommendation_service import (
    RecommendRequest,
    RecommendResponse,
)
from google.cloud.discoveryengine_v1beta.types.user_event import (
    CompletionInfo,
    DocumentInfo,
    MediaInfo,
    PageInfo,
    PanelInfo,
    SearchInfo,
    TransactionInfo,
    UserEvent,
)
from google.cloud.discoveryengine_v1beta.types.user_event_service import (
    CollectUserEventRequest,
    WriteUserEventRequest,
)

__all__ = (
    "DocumentServiceClient",
    "DocumentServiceAsyncClient",
    "RecommendationServiceClient",
    "RecommendationServiceAsyncClient",
    "UserEventServiceClient",
    "UserEventServiceAsyncClient",
    "CustomAttribute",
    "UserInfo",
    "Document",
    "CreateDocumentRequest",
    "DeleteDocumentRequest",
    "GetDocumentRequest",
    "ListDocumentsRequest",
    "ListDocumentsResponse",
    "UpdateDocumentRequest",
    "BigQuerySource",
    "GcsSource",
    "ImportDocumentsMetadata",
    "ImportDocumentsRequest",
    "ImportDocumentsResponse",
    "ImportErrorConfig",
    "ImportUserEventsMetadata",
    "ImportUserEventsRequest",
    "ImportUserEventsResponse",
    "RecommendRequest",
    "RecommendResponse",
    "CompletionInfo",
    "DocumentInfo",
    "MediaInfo",
    "PageInfo",
    "PanelInfo",
    "SearchInfo",
    "TransactionInfo",
    "UserEvent",
    "CollectUserEventRequest",
    "WriteUserEventRequest",
)



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import struct_pb2  # type: ignore
import proto  # type: ignore

from google.cloud.discoveryengine_v1beta.types import user_event as gcd_user_event
from google.cloud.discoveryengine_v1beta.types import document as gcd_document

__protobuf__ = proto.module(
    package="google.cloud.discoveryengine.v1beta",
    manifest={
        "RecommendRequest",
        "RecommendResponse",
    },
)


class RecommendRequest(proto.Message):
    r"""Request message for Recommend method.

    Attributes:
        serving_config (str):
            Required. Full resource name of the format:
            projects/\ */locations/global/collections/*/dataStores/*/servingConfigs/*

            Before you can request recommendations from your model, you
            must create at least one serving config for it.
        user_event (google.cloud.discoveryengine_v1beta.types.UserEvent):
            Required. Context about the user, what they are looking at
            and what action they took to trigger the Recommend request.
            Note that this user event detail won't be ingested to
            userEvent logs. Thus, a separate userEvent write request is
            required for event logging.

            Don't set
            [UserEvent.user_pseudo_id][google.cloud.discoveryengine.v1beta.UserEvent.user_pseudo_id]
            or
            [UserEvent.user_info.user_id][google.cloud.discoveryengine.v1beta.UserInfo.user_id]
            to the same fixed ID for different users. If you are trying
            to receive non-personalized recommendations (not
            recommended; this can negatively impact model performance),
            instead set
            [UserEvent.user_pseudo_id][google.cloud.discoveryengine.v1beta.UserEvent.user_pseudo_id]
            to a random unique ID and leave
            [UserEvent.user_info.user_id][google.cloud.discoveryengine.v1beta.UserInfo.user_id]
            unset.
        page_size (int):
            Maximum number of results to return. Set this
            property to the number of recommendation results
            needed. If zero, the service will choose a
            reasonable default. The maximum allowed value is
            100. Values above 100 will be coerced to 100.
        filter (str):
            Filter for restricting recommendation results with a length
            limit of 5,000 characters. Currently, only filter
            expressions on the ``filter_tags`` attribute is supported.

            Examples:

            -  (filter_tags: ANY("Red", "Blue") OR filter_tags:
               ANY("Hot", "Cold"))
            -  (filter_tags: ANY("Red", "Blue")) AND NOT (filter_tags:
               ANY("Green"))

            If your filter blocks all results, the API will return
            generic (unfiltered) popular Documents. If you only want
            results strictly matching the filters, set
            ``strictFiltering`` to True in
            [RecommendRequest.params][google.cloud.discoveryengine.v1beta.RecommendRequest.params]
            to receive empty results instead.

            Note that the API will never return Documents with
            storageStatus of "EXPIRED" or "DELETED" regardless of filter
            choices.
        validate_only (bool):
            Use validate only mode for this
            recommendation query. If set to true, a fake
            model will be used that returns arbitrary
            Document IDs. Note that the validate only mode
            should only be used for testing the API, or if
            the model is not ready.
        params (MutableMapping[str, google.protobuf.struct_pb2.Value]):
            Additional domain specific parameters for the
            recommendations.

            Allowed values:

            -  ``returnDocument``: Boolean. If set to true, the
               associated Document object will be returned in
               [RecommendResponse.results.document][RecommendationResult.document].
            -  ``returnScore``: Boolean. If set to true, the
               recommendation 'score' corresponding to each returned
               Document will be set in
               [RecommendResponse.results.metadata][RecommendationResult.metadata].
               The given 'score' indicates the probability of a Document
               conversion given the user's context and history.
            -  ``strictFiltering``: Boolean. True by default. If set to
               false, the service will return generic (unfiltered)
               popular Documents instead of empty if your filter blocks
               all recommendation results.
            -  ``diversityLevel``: String. Default empty. If set to be
               non-empty, then it needs to be one of:

               -  'no-diversity'
               -  'low-diversity'
               -  'medium-diversity'
               -  'high-diversity'
               -  'auto-diversity' This gives request-level control and
                  adjusts recommendation results based on Document
                  category.
        user_labels (MutableMapping[str, str]):
            The user labels applied to a resource must meet the
            following requirements:

            -  Each resource can have multiple labels, up to a maximum
               of 64.
            -  Each label must be a key-value pair.
            -  Keys have a minimum length of 1 character and a maximum
               length of 63 characters and cannot be empty. Values can
               be empty and have a maximum length of 63 characters.
            -  Keys and values can contain only lowercase letters,
               numeric characters, underscores, and dashes. All
               characters must use UTF-8 encoding, and international
               characters are allowed.
            -  The key portion of a label must be unique. However, you
               can use the same key with multiple resources.
            -  Keys must start with a lowercase letter or international
               character.

            See `Requirements for
            labels <https://cloud.google.com/resource-manager/docs/creating-managing-labels#requirements>`__
            for more details.
    """

    serving_config: str = proto.Field(
        proto.STRING,
        number=1,
    )
    user_event: gcd_user_event.UserEvent = proto.Field(
        proto.MESSAGE,
        number=2,
        message=gcd_user_event.UserEvent,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=3,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=4,
    )
    validate_only: bool = proto.Field(
        proto.BOOL,
        number=5,
    )
    params: MutableMapping[str, struct_pb2.Value] = proto.MapField(
        proto.STRING,
        proto.MESSAGE,
        number=6,
        message=struct_pb2.Value,
    )
    user_labels: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=8,
    )


class RecommendResponse(proto.Message):
    r"""Response message for Recommend method.

    Attributes:
        results (MutableSequence[google.cloud.discoveryengine_v1beta.types.RecommendResponse.RecommendationResult]):
            A list of recommended Documents. The order
            represents the ranking (from the most relevant
            Document to the least).
        attribution_token (str):
            A unique attribution token. This should be included in the
            [UserEvent][google.cloud.discoveryengine.v1beta.UserEvent]
            logs resulting from this recommendation, which enables
            accurate attribution of recommendation model performance.
        missing_ids (MutableSequence[str]):
            IDs of documents in the request that were
            missing from the default Branch associated with
            the requested ServingConfig.
        validate_only (bool):
            True if
            [RecommendRequest.validate_only][google.cloud.discoveryengine.v1beta.RecommendRequest.validate_only]
            was set.
    """

    class RecommendationResult(proto.Message):
        r"""RecommendationResult represents a generic recommendation
        result with associated metadata.

        Attributes:
            id (str):
                Resource ID of the recommended Document.
            document (google.cloud.discoveryengine_v1beta.types.Document):
                Set if ``returnDocument`` is set to true in
                [RecommendRequest.params][google.cloud.discoveryengine.v1beta.RecommendRequest.params].
            metadata (MutableMapping[str, google.protobuf.struct_pb2.Value]):
                Additional Document metadata / annotations.

                Possible values:

                -  ``score``: Recommendation score in double value. Is set
                   if ``returnScore`` is set to true in
                   [RecommendRequest.params][google.cloud.discoveryengine.v1beta.RecommendRequest.params].
        """

        id: str = proto.Field(
            proto.STRING,
            number=1,
        )
        document: gcd_document.Document = proto.Field(
            proto.MESSAGE,
            number=2,
            message=gcd_document.Document,
        )
        metadata: MutableMapping[str, struct_pb2.Value] = proto.MapField(
            proto.STRING,
            proto.MESSAGE,
            number=3,
            message=struct_pb2.Value,
        )

    results: MutableSequence[RecommendationResult] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=RecommendationResult,
    )
    attribution_token: str = proto.Field(
        proto.STRING,
        number=2,
    )
    missing_ids: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )
    validate_only: bool = proto.Field(
        proto.BOOL,
        number=4,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import struct_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.discoveryengine.v1beta",
    manifest={
        "Document",
    },
)


class Document(proto.Message):
    r"""Document captures all raw metadata information of items to be
    recommended or searched.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        struct_data (google.protobuf.struct_pb2.Struct):
            The structured JSON data for the document. It should conform
            to the registered [schema][] or an INVALID_ARGUMENT error is
            thrown.

            This field is a member of `oneof`_ ``data``.
        json_data (str):
            The JSON string representation of the document. It should
            conform to the registered [schema][] or an INVALID_ARGUMENT
            error is thrown.

            This field is a member of `oneof`_ ``data``.
        name (str):
            Immutable. The full resource name of the document. Format:
            ``projects/{project}/locations/{location}/collections/{collection}/dataStores/{data_store}/branches/{branch}/documents/{document_id}``.

            This field must be a UTF-8 encoded string with a length
            limit of 1024 characters.
        id (str):
            Immutable. The identifier of the document.

            Id should conform to
            `RFC-1034 <https://tools.ietf.org/html/rfc1034>`__ standard
            with a length limit of 63 characters.
        schema_id (str):
            The identifier of the schema located in the
            same data store.
        parent_document_id (str):
            The identifier of the parent document. Currently supports at
            most two level document hierarchy.

            Id should conform to
            `RFC-1034 <https://tools.ietf.org/html/rfc1034>`__ standard
            with a length limit of 63 characters.
    """

    struct_data: struct_pb2.Struct = proto.Field(
        proto.MESSAGE,
        number=4,
        oneof="data",
        message=struct_pb2.Struct,
    )
    json_data: str = proto.Field(
        proto.STRING,
        number=5,
        oneof="data",
    )
    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    schema_id: str = proto.Field(
        proto.STRING,
        number=3,
    )
    parent_document_id: str = proto.Field(
        proto.STRING,
        number=7,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
from google.rpc import status_pb2  # type: ignore
from google.type import date_pb2  # type: ignore
import proto  # type: ignore

from google.cloud.discoveryengine_v1beta.types import document, user_event

__protobuf__ = proto.module(
    package="google.cloud.discoveryengine.v1beta",
    manifest={
        "GcsSource",
        "BigQuerySource",
        "ImportErrorConfig",
        "ImportUserEventsRequest",
        "ImportUserEventsResponse",
        "ImportUserEventsMetadata",
        "ImportDocumentsMetadata",
        "ImportDocumentsRequest",
        "ImportDocumentsResponse",
    },
)


class GcsSource(proto.Message):
    r"""Cloud Storage location for input content.

    Attributes:
        input_uris (MutableSequence[str]):
            Required. Cloud Storage URIs to input files. URI can be up
            to 2000 characters long. URIs can match the full object path
            (for example, ``gs://bucket/directory/object.json``) or a
            pattern matching one or more files, such as
            ``gs://bucket/directory/*.json``. A request can contain at
            most 100 files, and each file can be up to 2 GB.
        data_schema (str):
            The schema to use when parsing the data from the source.

            Supported values for document imports:

            -  ``document`` (default): One JSON
               [Document][google.cloud.discoveryengine.v1beta.Document]
               per line. Each document must have a valid
               [Document.id][google.cloud.discoveryengine.v1beta.Document.id].

            Supported values for user even imports:

            -  ``user_event`` (default): One JSON
               [UserEvent][google.cloud.discoveryengine.v1beta.UserEvent]
               per line.
    """

    input_uris: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=1,
    )
    data_schema: str = proto.Field(
        proto.STRING,
        number=2,
    )


class BigQuerySource(proto.Message):
    r"""BigQuery source import data from.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        partition_date (google.type.date_pb2.Date):
            BigQuery time partitioned table's \_PARTITIONDATE in
            YYYY-MM-DD format.

            This field is a member of `oneof`_ ``partition``.
        project_id (str):
            The project ID (can be project # or ID) that
            the BigQuery source is in with a length limit of
            128 characters. If not specified, inherits the
            project ID from the parent request.
        dataset_id (str):
            Required. The BigQuery data set to copy the
            data from with a length limit of 1,024
            characters.
        table_id (str):
            Required. The BigQuery table to copy the data
            from with a length limit of 1,024 characters.
        gcs_staging_dir (str):
            Intermediate Cloud Storage directory used for
            the import with a length limit of 2,000
            characters. Can be specified if one wants to
            have the BigQuery export to a specific Cloud
            Storage directory.
        data_schema (str):
            The schema to use when parsing the data from the source.

            Supported values for imports:

            -  ``user_event`` (default): One JSON
               [UserEvent][google.cloud.discoveryengine.v1beta.UserEvent]
               per line.

            -  ``document`` (default): One JSON
               [Document][google.cloud.discoveryengine.v1beta.Document]
               per line. Each document must have a valid
               [document.id][].
    """

    partition_date: date_pb2.Date = proto.Field(
        proto.MESSAGE,
        number=5,
        oneof="partition",
        message=date_pb2.Date,
    )
    project_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    dataset_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    table_id: str = proto.Field(
        proto.STRING,
        number=3,
    )
    gcs_staging_dir: str = proto.Field(
        proto.STRING,
        number=4,
    )
    data_schema: str = proto.Field(
        proto.STRING,
        number=6,
    )


class ImportErrorConfig(proto.Message):
    r"""Configuration of destination for Import related errors.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        gcs_prefix (str):
            Cloud Storage prefix for import errors. This must be an
            empty, existing Cloud Storage directory. Import errors will
            be written to sharded files in this directory, one per line,
            as a JSON-encoded ``google.rpc.Status`` message.

            This field is a member of `oneof`_ ``destination``.
    """

    gcs_prefix: str = proto.Field(
        proto.STRING,
        number=1,
        oneof="destination",
    )


class ImportUserEventsRequest(proto.Message):
    r"""Request message for the ImportUserEvents request.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        inline_source (google.cloud.discoveryengine_v1beta.types.ImportUserEventsRequest.InlineSource):
            Required. The Inline source for the input
            content for UserEvents.

            This field is a member of `oneof`_ ``source``.
        gcs_source (google.cloud.discoveryengine_v1beta.types.GcsSource):
            Required. Cloud Storage location for the
            input content.

            This field is a member of `oneof`_ ``source``.
        bigquery_source (google.cloud.discoveryengine_v1beta.types.BigQuerySource):
            Required. BigQuery input source.

            This field is a member of `oneof`_ ``source``.
        parent (str):
            Required. Parent DataStore resource name, of the form
            ``projects/{project}/locations/{location}/collections/{collection}/dataStores/{data_store}``
        error_config (google.cloud.discoveryengine_v1beta.types.ImportErrorConfig):
            The desired location of errors incurred
            during the Import. Cannot be set for inline user
            event imports.
    """

    class InlineSource(proto.Message):
        r"""The inline source for the input config for ImportUserEvents
        method.

        Attributes:
            user_events (MutableSequence[google.cloud.discoveryengine_v1beta.types.UserEvent]):
                Required. A list of user events to import.
                Recommended max of 10k items.
        """

        user_events: MutableSequence[user_event.UserEvent] = proto.RepeatedField(
            proto.MESSAGE,
            number=1,
            message=user_event.UserEvent,
        )

    inline_source: InlineSource = proto.Field(
        proto.MESSAGE,
        number=2,
        oneof="source",
        message=InlineSource,
    )
    gcs_source: "GcsSource" = proto.Field(
        proto.MESSAGE,
        number=3,
        oneof="source",
        message="GcsSource",
    )
    bigquery_source: "BigQuerySource" = proto.Field(
        proto.MESSAGE,
        number=4,
        oneof="source",
        message="BigQuerySource",
    )
    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    error_config: "ImportErrorConfig" = proto.Field(
        proto.MESSAGE,
        number=5,
        message="ImportErrorConfig",
    )


class ImportUserEventsResponse(proto.Message):
    r"""Response of the ImportUserEventsRequest. If the long running
    operation was successful, then this message is returned by the
    google.longrunning.Operations.response field if the operation
    was successful.

    Attributes:
        error_samples (MutableSequence[google.rpc.status_pb2.Status]):
            A sample of errors encountered while
            processing the request.
        error_config (google.cloud.discoveryengine_v1beta.types.ImportErrorConfig):
            Echoes the destination for the complete
            errors if this field was set in the request.
        joined_events_count (int):
            Count of user events imported with complete
            existing Documents.
        unjoined_events_count (int):
            Count of user events imported, but with
            Document information not found in the existing
            Branch.
    """

    error_samples: MutableSequence[status_pb2.Status] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=status_pb2.Status,
    )
    error_config: "ImportErrorConfig" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="ImportErrorConfig",
    )
    joined_events_count: int = proto.Field(
        proto.INT64,
        number=3,
    )
    unjoined_events_count: int = proto.Field(
        proto.INT64,
        number=4,
    )


class ImportUserEventsMetadata(proto.Message):
    r"""Metadata related to the progress of the Import operation.
    This will be returned by the
    google.longrunning.Operation.metadata field.

    Attributes:
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Operation create time.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Operation last update time. If the operation
            is done, this is also the finish time.
        success_count (int):
            Count of entries that were processed
            successfully.
        failure_count (int):
            Count of entries that encountered errors
            while processing.
    """

    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=1,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )
    success_count: int = proto.Field(
        proto.INT64,
        number=3,
    )
    failure_count: int = proto.Field(
        proto.INT64,
        number=4,
    )


class ImportDocumentsMetadata(proto.Message):
    r"""Metadata related to the progress of the ImportDocuments
    operation. This will be returned by the
    google.longrunning.Operation.metadata field.

    Attributes:
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Operation create time.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Operation last update time. If the operation
            is done, this is also the finish time.
        success_count (int):
            Count of entries that were processed
            successfully.
        failure_count (int):
            Count of entries that encountered errors
            while processing.
    """

    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=1,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )
    success_count: int = proto.Field(
        proto.INT64,
        number=3,
    )
    failure_count: int = proto.Field(
        proto.INT64,
        number=4,
    )


class ImportDocumentsRequest(proto.Message):
    r"""Request message for Import methods.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        inline_source (google.cloud.discoveryengine_v1beta.types.ImportDocumentsRequest.InlineSource):
            The Inline source for the input content for
            documents.

            This field is a member of `oneof`_ ``source``.
        gcs_source (google.cloud.discoveryengine_v1beta.types.GcsSource):
            Cloud Storage location for the input content.

            This field is a member of `oneof`_ ``source``.
        bigquery_source (google.cloud.discoveryengine_v1beta.types.BigQuerySource):
            BigQuery input source.

            This field is a member of `oneof`_ ``source``.
        parent (str):
            Required. The parent branch resource name, such as
            ``projects/{project}/locations/{location}/collections/{collection}/dataStores/{data_store}/branches/{branch}``.
            Requires create/update permission.
        error_config (google.cloud.discoveryengine_v1beta.types.ImportErrorConfig):
            The desired location of errors incurred
            during the Import.
        reconciliation_mode (google.cloud.discoveryengine_v1beta.types.ImportDocumentsRequest.ReconciliationMode):
            The mode of reconciliation between existing documents and
            the documents to be imported. Defaults to
            [ReconciliationMode.INCREMENTAL][google.cloud.discoveryengine.v1beta.ImportDocumentsRequest.ReconciliationMode.INCREMENTAL].
    """

    class ReconciliationMode(proto.Enum):
        r"""Indicates how imported documents are reconciled with the
        existing documents created or imported before.

        Values:
            RECONCILIATION_MODE_UNSPECIFIED (0):
                Defaults to INCREMENTAL.
            INCREMENTAL (1):
                Inserts new documents or updates existing
                documents.
            FULL (2):
                Calculates diff and replaces the entire
                document dataset. Existing documents may be
                deleted if they are not present in the source
                location.
        """
        RECONCILIATION_MODE_UNSPECIFIED = 0
        INCREMENTAL = 1
        FULL = 2

    class InlineSource(proto.Message):
        r"""The inline source for the input config for ImportDocuments
        method.

        Attributes:
            documents (MutableSequence[google.cloud.discoveryengine_v1beta.types.Document]):
                Required. A list of documents to update/create. Each
                document must have a valid
                [Document.id][google.cloud.discoveryengine.v1beta.Document.id].
                Recommended max of 100 items.
        """

        documents: MutableSequence[document.Document] = proto.RepeatedField(
            proto.MESSAGE,
            number=1,
            message=document.Document,
        )

    inline_source: InlineSource = proto.Field(
        proto.MESSAGE,
        number=2,
        oneof="source",
        message=InlineSource,
    )
    gcs_source: "GcsSource" = proto.Field(
        proto.MESSAGE,
        number=3,
        oneof="source",
        message="GcsSource",
    )
    bigquery_source: "BigQuerySource" = proto.Field(
        proto.MESSAGE,
        number=4,
        oneof="source",
        message="BigQuerySource",
    )
    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    error_config: "ImportErrorConfig" = proto.Field(
        proto.MESSAGE,
        number=5,
        message="ImportErrorConfig",
    )
    reconciliation_mode: ReconciliationMode = proto.Field(
        proto.ENUM,
        number=6,
        enum=ReconciliationMode,
    )


class ImportDocumentsResponse(proto.Message):
    r"""Response of the
    [ImportDocumentsRequest][google.cloud.discoveryengine.v1beta.ImportDocumentsRequest].
    If the long running operation is done, then this message is returned
    by the google.longrunning.Operations.response field if the operation
    was successful.

    Attributes:
        error_samples (MutableSequence[google.rpc.status_pb2.Status]):
            A sample of errors encountered while
            processing the request.
        error_config (google.cloud.discoveryengine_v1beta.types.ImportErrorConfig):
            Echoes the destination for the complete
            errors in the request if set.
    """

    error_samples: MutableSequence[status_pb2.Status] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=status_pb2.Status,
    )
    error_config: "ImportErrorConfig" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="ImportErrorConfig",
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import duration_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

from google.cloud.discoveryengine_v1beta.types import common

__protobuf__ = proto.module(
    package="google.cloud.discoveryengine.v1beta",
    manifest={
        "UserEvent",
        "PageInfo",
        "SearchInfo",
        "CompletionInfo",
        "TransactionInfo",
        "DocumentInfo",
        "PanelInfo",
        "MediaInfo",
    },
)


class UserEvent(proto.Message):
    r"""UserEvent captures all metadata information Discovery Engine
    API needs to know about how end users interact with customers'
    website.

    Attributes:
        event_type (str):
            Required. User event type. Allowed values are:

            Generic values:

            -  ``search``: Search for Documents.
            -  ``view-item``: Detailed page view of a Document.
            -  ``view-item-list``: View of a panel or ordered list of
               Documents.
            -  ``view-home-page``: View of the home page.
            -  ``view-category-page``: View of a category page, e.g.
               Home > Men > Jeans

            Retail-related values:

            -  ``add-to-cart``: Add an item(s) to cart, e.g. in Retail
               online shopping
            -  ``purchase``: Purchase an item(s)

            Media-related values:

            -  ``media-play``: Start/resume watching a video, playing a
               song, etc.
            -  ``media-complete``: Finished or stopped midway through a
               video, song, etc.
        user_pseudo_id (str):
            Required. A unique identifier for tracking visitors.

            For example, this could be implemented with an HTTP cookie,
            which should be able to uniquely identify a visitor on a
            single device. This unique identifier should not change if
            the visitor log in/out of the website.

            Do not set the field to the same fixed ID for different
            users. This mixes the event history of those users together,
            which results in degraded model quality.

            The field must be a UTF-8 encoded string with a length limit
            of 128 characters. Otherwise, an INVALID_ARGUMENT error is
            returned.

            The field should not contain PII or user-data. We recommend
            to use Google Analytics `Client
            ID <https://developers.google.com/analytics/devguides/collection/analyticsjs/field-reference#clientId>`__
            for this field.
        event_time (google.protobuf.timestamp_pb2.Timestamp):
            Only required for
            [UserEventService.ImportUserEvents][google.cloud.discoveryengine.v1beta.UserEventService.ImportUserEvents]
            method. Timestamp of when the user event happened.
        user_info (google.cloud.discoveryengine_v1beta.types.UserInfo):
            Information about the end user.
        direct_user_request (bool):
            Should set to true if the request is made directly from the
            end user, in which case the
            [UserEvent.user_info.user_agent][google.cloud.discoveryengine.v1beta.UserInfo.user_agent]
            can be populated from the HTTP request.

            This flag should be set only if the API request is made
            directly from the end user such as a mobile app (and not if
            a gateway or a server is processing and pushing the user
            events).

            This should not be set when using the JavaScript tag in
            [UserEventService.CollectUserEvent][google.cloud.discoveryengine.v1beta.UserEventService.CollectUserEvent].
        session_id (str):
            A unique identifier for tracking a visitor session with a
            length limit of 128 bytes. A session is an aggregation of an
            end user behavior in a time span.

            A general guideline to populate the session_id:

            1. If user has no activity for 30 min, a new session_id
               should be assigned.
            2. The session_id should be unique across users, suggest use
               uuid or add
               [UserEvent.user_pseudo_id][google.cloud.discoveryengine.v1beta.UserEvent.user_pseudo_id]
               as prefix.
        page_info (google.cloud.discoveryengine_v1beta.types.PageInfo):
            Page metadata such as categories and other critical
            information for certain event types such as
            ``view-category-page``.
        attribution_token (str):
            Token to attribute an API response to user action(s) to
            trigger the event.

            Highly recommended for user events that are the result of
            [PredictionService.Predict][]. This field enables accurate
            attribution of recommendation model performance.

            The value must be one of:

            -  [PredictResponse.attribution_token][] for events that are
               the result of [PredictionService.Predict][].
            -  [SearchResponse.attribution_token][google.cloud.discoveryengine.v1beta.SearchResponse.attribution_token]
               for events that are the result of
               [SearchService.Search][].
            -  [CompleteQueryResponse.attribution_token][] for events
               that are the result of [SearchService.CompleteQuery][].

            This token enables us to accurately attribute page view or
            conversion completion back to the event and the particular
            predict response containing this clicked/purchased product.
            If user clicks on product K in the recommendation results,
            pass [PredictResponse.attribution_token][] as a URL
            parameter to product K's page. When recording events on
            product K's page, log the
            [PredictResponse.attribution_token][] to this field.
        filter (str):
            The filter syntax consists of an expression language for
            constructing a predicate from one or more fields of the
            documents being filtered.

            One example is for ``search`` events, the associated
            [SearchService.SearchRequest][] may contain a filter
            expression in [SearchService.SearchRequest.filter][]
            conforming to https://google.aip.dev/160#filtering.

            Similarly, for ``view-item-list`` events that are generated
            from a [PredictionService.PredictRequest][], this field may
            be populated directly from
            [PredictionService.PredictRequest.filter][] conforming to
            https://google.aip.dev/160#filtering.

            The value must be a UTF-8 encoded string with a length limit
            of 1,000 characters. Otherwise, an INVALID_ARGUMENT error is
            returned.
        documents (MutableSequence[google.cloud.discoveryengine_v1beta.types.DocumentInfo]):
            List of Documents associated with this user event.

            This field is optional except for the following event types:

            -  ``view-item``
            -  ``add-to-cart``
            -  ``purchase``
            -  ``media-play``
            -  ``media-complete``

            In a ``search`` event, this field represents the documents
            returned to the end user on the current page (the end user
            may have not finished browsing the whole page yet). When a
            new page is returned to the end user, after
            pagination/filtering/ordering even for the same query, a new
            ``search`` event with different
            [UserEvent.documents][google.cloud.discoveryengine.v1beta.UserEvent.documents]
            is desired.
        panel (google.cloud.discoveryengine_v1beta.types.PanelInfo):
            Panel metadata associated with this user
            event.
        search_info (google.cloud.discoveryengine_v1beta.types.SearchInfo):
            Search API details related to the event.

            This field should be set for ``search`` event.
        completion_info (google.cloud.discoveryengine_v1beta.types.CompletionInfo):
            CompleteQuery API details related to the event.

            This field should be set for ``search`` event when
            autocomplete function is enabled and the user clicks a
            suggestion for search.
        transaction_info (google.cloud.discoveryengine_v1beta.types.TransactionInfo):
            The transaction metadata (if any) associated
            with this user event.
        tag_ids (MutableSequence[str]):
            A list of identifiers for the independent
            experiment groups this user event belongs to.
            This is used to distinguish between user events
            associated with different experiment setups on
            the customer end.
        promotion_ids (MutableSequence[str]):
            The promotion IDs if this is an event
            associated with promotions. Currently, this
            field is restricted to at most one ID.
        attributes (MutableMapping[str, google.cloud.discoveryengine_v1beta.types.CustomAttribute]):
            Extra user event features to include in the recommendation
            model. These attributes must NOT contain data that needs to
            be parsed or processed further, e.g. JSON or other
            encodings.

            If you provide custom attributes for ingested user events,
            also include them in the user events that you associate with
            prediction requests. Custom attribute formatting must be
            consistent between imported events and events provided with
            prediction requests. This lets the Discovery Engine API use
            those custom attributes when training models and serving
            predictions, which helps improve recommendation quality.

            This field needs to pass all below criteria, otherwise an
            INVALID_ARGUMENT error is returned:

            -  The key must be a UTF-8 encoded string with a length
               limit of 5,000 characters.
            -  For text attributes, at most 400 values are allowed.
               Empty values are not allowed. Each value must be a UTF-8
               encoded string with a length limit of 256 characters.
            -  For number attributes, at most 400 values are allowed.

            For product recommendations, an example of extra user
            information is traffic_channel, which is how a user arrives
            at the site. Users can arrive at the site by coming to the
            site directly, coming through Google search, or in other
            ways.
        media_info (google.cloud.discoveryengine_v1beta.types.MediaInfo):
            Media-specific info.
    """

    event_type: str = proto.Field(
        proto.STRING,
        number=1,
    )
    user_pseudo_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    event_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=3,
        message=timestamp_pb2.Timestamp,
    )
    user_info: common.UserInfo = proto.Field(
        proto.MESSAGE,
        number=4,
        message=common.UserInfo,
    )
    direct_user_request: bool = proto.Field(
        proto.BOOL,
        number=5,
    )
    session_id: str = proto.Field(
        proto.STRING,
        number=6,
    )
    page_info: "PageInfo" = proto.Field(
        proto.MESSAGE,
        number=7,
        message="PageInfo",
    )
    attribution_token: str = proto.Field(
        proto.STRING,
        number=8,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=9,
    )
    documents: MutableSequence["DocumentInfo"] = proto.RepeatedField(
        proto.MESSAGE,
        number=10,
        message="DocumentInfo",
    )
    panel: "PanelInfo" = proto.Field(
        proto.MESSAGE,
        number=11,
        message="PanelInfo",
    )
    search_info: "SearchInfo" = proto.Field(
        proto.MESSAGE,
        number=12,
        message="SearchInfo",
    )
    completion_info: "CompletionInfo" = proto.Field(
        proto.MESSAGE,
        number=13,
        message="CompletionInfo",
    )
    transaction_info: "TransactionInfo" = proto.Field(
        proto.MESSAGE,
        number=14,
        message="TransactionInfo",
    )
    tag_ids: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=15,
    )
    promotion_ids: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=16,
    )
    attributes: MutableMapping[str, common.CustomAttribute] = proto.MapField(
        proto.STRING,
        proto.MESSAGE,
        number=17,
        message=common.CustomAttribute,
    )
    media_info: "MediaInfo" = proto.Field(
        proto.MESSAGE,
        number=18,
        message="MediaInfo",
    )


class PageInfo(proto.Message):
    r"""Detailed page information.

    Attributes:
        pageview_id (str):
            A unique ID of a web page view.

            This should be kept the same for all user events triggered
            from the same pageview. For example, an item detail page
            view could trigger multiple events as the user is browsing
            the page. The ``pageViewId`` property should be kept the
            same for all these events so that they can be grouped
            together properly.

            When using the client side event reporting with JavaScript
            pixel and Google Tag Manager, this value is filled in
            automatically.
        page_category (str):
            The most specific category associated with a category page.

            To represent full path of category, use '>' sign to separate
            different hierarchies. If '>' is part of the category name,
            please replace it with other character(s).

            Category pages include special pages such as sales or
            promotions. For instance, a special sale page may have the
            category hierarchy: "pageCategory" : "Sales > 2017 Black
            Friday Deals".

            Required for ``view-category-page`` events. Other event
            types should not set this field. Otherwise, an
            INVALID_ARGUMENT error is returned.
        uri (str):
            Complete URL (window.location.href) of the
            user's current page.
            When using the client side event reporting with
            JavaScript pixel and Google Tag Manager, this
            value is filled in automatically. Maximum length
            5,000 characters.
        referrer_uri (str):
            The referrer URL of the current page.
            When using the client side event reporting with
            JavaScript pixel and Google Tag Manager, this
            value is filled in automatically. However, some
            browser privacy restrictions may cause this
            field to be empty.
    """

    pageview_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_category: str = proto.Field(
        proto.STRING,
        number=2,
    )
    uri: str = proto.Field(
        proto.STRING,
        number=3,
    )
    referrer_uri: str = proto.Field(
        proto.STRING,
        number=4,
    )


class SearchInfo(proto.Message):
    r"""Detailed search information.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        search_query (str):
            The user's search query.

            See
            [SearchRequest.query][google.cloud.discoveryengine.v1beta.SearchRequest.query]
            for definition.

            The value must be a UTF-8 encoded string with a length limit
            of 5,000 characters. Otherwise, an INVALID_ARGUMENT error is
            returned.

            At least one of
            [search_query][google.cloud.discoveryengine.v1beta.SearchInfo.search_query]
            or [page_categories][] is required for ``search`` events.
            Other event types should not set this field. Otherwise, an
            INVALID_ARGUMENT error is returned.
        order_by (str):
            The order in which products are returned, if applicable.

            See
            [SearchRequest.order_by][google.cloud.discoveryengine.v1beta.SearchRequest.order_by]
            for definition and syntax.

            The value must be a UTF-8 encoded string with a length limit
            of 1,000 characters. Otherwise, an INVALID_ARGUMENT error is
            returned.

            This can only be set for ``search`` events. Other event
            types should not set this field. Otherwise, an
            INVALID_ARGUMENT error is returned.
        offset (int):
            An integer that specifies the current offset for pagination
            (the 0-indexed starting location, amongst the products
            deemed by the API as relevant).

            See
            [SearchRequest.offset][google.cloud.discoveryengine.v1beta.SearchRequest.offset]
            for definition.

            If this field is negative, an INVALID_ARGUMENT is returned.

            This can only be set for ``search`` events. Other event
            types should not set this field. Otherwise, an
            INVALID_ARGUMENT error is returned.

            This field is a member of `oneof`_ ``_offset``.
    """

    search_query: str = proto.Field(
        proto.STRING,
        number=1,
    )
    order_by: str = proto.Field(
        proto.STRING,
        number=2,
    )
    offset: int = proto.Field(
        proto.INT32,
        number=3,
        optional=True,
    )


class CompletionInfo(proto.Message):
    r"""Detailed completion information including completion
    attribution token and clicked completion info.

    Attributes:
        selected_suggestion (str):
            End user selected
            [CompleteQueryResponse.CompletionResult.suggestion][].
        selected_position (int):
            End user selected
            [CompleteQueryResponse.CompletionResult.suggestion][]
            position, starting from 0.
    """

    selected_suggestion: str = proto.Field(
        proto.STRING,
        number=1,
    )
    selected_position: int = proto.Field(
        proto.INT32,
        number=2,
    )


class TransactionInfo(proto.Message):
    r"""A transaction represents the entire purchase transaction.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        value (float):
            Required. Total non-zero value associated
            with the transaction. This value may include
            shipping, tax, or other adjustments to the total
            value that you want to include.

            This field is a member of `oneof`_ ``_value``.
        currency (str):
            Required. Currency code. Use three-character
            ISO-4217 code.
        transaction_id (str):
            The transaction ID with a length limit of 128
            characters.
        tax (float):
            All the taxes associated with the
            transaction.

            This field is a member of `oneof`_ ``_tax``.
        cost (float):
            All the costs associated with the products. These can be
            manufacturing costs, shipping expenses not borne by the end
            user, or any other costs, such that:

            -  Profit =
               [value][google.cloud.discoveryengine.v1beta.TransactionInfo.value]
               -
               [tax][google.cloud.discoveryengine.v1beta.TransactionInfo.tax]
               -
               [cost][google.cloud.discoveryengine.v1beta.TransactionInfo.cost]

            This field is a member of `oneof`_ ``_cost``.
        discount_value (float):
            The total discount(s) value applied to this transaction.
            This figure should be excluded from
            [TransactionInfo.value][google.cloud.discoveryengine.v1beta.TransactionInfo.value]

            For example, if a user paid
            [TransactionInfo.value][google.cloud.discoveryengine.v1beta.TransactionInfo.value]
            amount, then nominal (pre-discount) value of the transaction
            is the sum of
            [TransactionInfo.value][google.cloud.discoveryengine.v1beta.TransactionInfo.value]
            and
            [TransactionInfo.discount_value][google.cloud.discoveryengine.v1beta.TransactionInfo.discount_value]

            This means that profit is calculated the same way,
            regardless of the discount value, and that
            [TransactionInfo.discount_value][google.cloud.discoveryengine.v1beta.TransactionInfo.discount_value]
            can be larger than
            [TransactionInfo.value][google.cloud.discoveryengine.v1beta.TransactionInfo.value]:

            -  Profit =
               [value][google.cloud.discoveryengine.v1beta.TransactionInfo.value]
               -
               [tax][google.cloud.discoveryengine.v1beta.TransactionInfo.tax]
               -
               [cost][google.cloud.discoveryengine.v1beta.TransactionInfo.cost]

            This field is a member of `oneof`_ ``_discount_value``.
    """

    value: float = proto.Field(
        proto.FLOAT,
        number=1,
        optional=True,
    )
    currency: str = proto.Field(
        proto.STRING,
        number=2,
    )
    transaction_id: str = proto.Field(
        proto.STRING,
        number=3,
    )
    tax: float = proto.Field(
        proto.FLOAT,
        number=4,
        optional=True,
    )
    cost: float = proto.Field(
        proto.FLOAT,
        number=5,
        optional=True,
    )
    discount_value: float = proto.Field(
        proto.FLOAT,
        number=6,
        optional=True,
    )


class DocumentInfo(proto.Message):
    r"""Detailed document information associated with a user event.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        id (str):
            Required. The Document resource ID.

            This field is a member of `oneof`_ ``document_descriptor``.
        name (str):
            Required. The Document resource full name, of the form:
            projects/{project_id}/locations/{location}/collections/{collection_id}/dataStores/{data_store_id}/branches/{branch_id}/documents/{document_id}

            This field is a member of `oneof`_ ``document_descriptor``.
        quantity (int):
            Quantity of the Document associated with the user event.
            Defaults to 1.

            For example, this field will be 2 if two quantities of the
            same Document are involved in a ``add-to-cart`` event.

            Required for events of the following event types:

            -  ``add-to-cart``
            -  ``purchase``

            This field is a member of `oneof`_ ``_quantity``.
        promotion_ids (MutableSequence[str]):
            The promotion IDs associated with this
            Document. Currently, this field is restricted to
            at most one ID.
    """

    id: str = proto.Field(
        proto.STRING,
        number=1,
        oneof="document_descriptor",
    )
    name: str = proto.Field(
        proto.STRING,
        number=2,
        oneof="document_descriptor",
    )
    quantity: int = proto.Field(
        proto.INT32,
        number=3,
        optional=True,
    )
    promotion_ids: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=4,
    )


class PanelInfo(proto.Message):
    r"""Detailed panel information associated with a user event.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        panel_id (str):
            Required. The panel ID.
        display_name (str):
            The display name of the panel.
        panel_position (int):
            The ordered position of the panel, if shown to the user with
            other panels. If set, then
            [total_panels][google.cloud.discoveryengine.v1beta.PanelInfo.total_panels]
            must also be set.

            This field is a member of `oneof`_ ``_panel_position``.
        total_panels (int):
            The total number of panels, including this one, shown to the
            user. Must be set if
            [panel_position][google.cloud.discoveryengine.v1beta.PanelInfo.panel_position]
            is set.

            This field is a member of `oneof`_ ``_total_panels``.
    """

    panel_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=3,
    )
    panel_position: int = proto.Field(
        proto.INT32,
        number=4,
        optional=True,
    )
    total_panels: int = proto.Field(
        proto.INT32,
        number=5,
        optional=True,
    )


class MediaInfo(proto.Message):
    r"""Media-specific user event information.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        media_progress_duration (google.protobuf.duration_pb2.Duration):
            The media progress time in seconds, if applicable. For
            example, if the end user has finished 90 seconds of a
            playback video, then
            [MediaInfo.media_progress_duration.seconds][Duration.seconds]
            should be set to 90.
        media_progress_percentage (float):
            Media progress should be computed using only the
            media_progress_duration relative to the media total length.

            This value must be between [0, 1.0] inclusive.

            If this is not a playback or the progress cannot be computed
            (e.g. ongoing livestream), this field should be unset.

            This field is a member of `oneof`_ ``_media_progress_percentage``.
    """

    media_progress_duration: duration_pb2.Duration = proto.Field(
        proto.MESSAGE,
        number=1,
        message=duration_pb2.Duration,
    )
    media_progress_percentage: float = proto.Field(
        proto.FLOAT,
        number=2,
        optional=True,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.discoveryengine.v1beta",
    manifest={
        "CustomAttribute",
        "UserInfo",
    },
)


class CustomAttribute(proto.Message):
    r"""A custom attribute that is not explicitly modeled in a resource,
    e.g. [UserEvent][google.cloud.discoveryengine.v1beta.UserEvent].

    Attributes:
        text (MutableSequence[str]):
            The textual values of this custom attribute. For example,
            ``["yellow", "green"]`` when the key is "color".

            Empty string is not allowed. Otherwise, an INVALID_ARGUMENT
            error is returned.

            Exactly one of
            [text][google.cloud.discoveryengine.v1beta.CustomAttribute.text]
            or
            [numbers][google.cloud.discoveryengine.v1beta.CustomAttribute.numbers]
            should be set. Otherwise, an INVALID_ARGUMENT error is
            returned.
        numbers (MutableSequence[float]):
            The numerical values of this custom attribute. For example,
            ``[2.3, 15.4]`` when the key is "lengths_cm".

            Exactly one of
            [text][google.cloud.discoveryengine.v1beta.CustomAttribute.text]
            or
            [numbers][google.cloud.discoveryengine.v1beta.CustomAttribute.numbers]
            should be set. Otherwise, an INVALID_ARGUMENT error is
            returned.
    """

    text: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=1,
    )
    numbers: MutableSequence[float] = proto.RepeatedField(
        proto.DOUBLE,
        number=2,
    )


class UserInfo(proto.Message):
    r"""Information of an end user.

    Attributes:
        user_id (str):
            Highly recommended for logged-in users. Unique identifier
            for logged-in user, such as a user name. Don't set for
            anonymous users.

            Always use a hashed value for this ID.

            Don't set the field to the same fixed ID for different
            users. This mixes the event history of those users together,
            which results in degraded model quality.

            The field must be a UTF-8 encoded string with a length limit
            of 128 characters. Otherwise, an INVALID_ARGUMENT error is
            returned.
        user_agent (str):
            User agent as included in the HTTP header. Required for
            getting [SearchResponse.sponsored_results][].

            The field must be a UTF-8 encoded string with a length limit
            of 1,000 characters. Otherwise, an INVALID_ARGUMENT error is
            returned.

            This should not be set when using the client side event
            reporting with GTM or JavaScript tag in
            [UserEventService.CollectUserEvent][google.cloud.discoveryengine.v1beta.UserEventService.CollectUserEvent]
            or if [direct_user_request][] is set.
    """

    user_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    user_agent: str = proto.Field(
        proto.STRING,
        number=2,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.cloud.discoveryengine_v1beta.types import document as gcd_document

__protobuf__ = proto.module(
    package="google.cloud.discoveryengine.v1beta",
    manifest={
        "GetDocumentRequest",
        "ListDocumentsRequest",
        "ListDocumentsResponse",
        "CreateDocumentRequest",
        "UpdateDocumentRequest",
        "DeleteDocumentRequest",
    },
)


class GetDocumentRequest(proto.Message):
    r"""Request message for
    [DocumentService.GetDocument][google.cloud.discoveryengine.v1beta.DocumentService.GetDocument]
    method.

    Attributes:
        name (str):
            Required. Full resource name of
            [Document][google.cloud.discoveryengine.v1beta.Document],
            such as
            ``projects/{project}/locations/{location}/collections/{collection}/dataStores/{data_store}/branches/{branch}/documents/{document}``.

            If the caller does not have permission to access the
            [Document][google.cloud.discoveryengine.v1beta.Document],
            regardless of whether or not it exists, a PERMISSION_DENIED
            error is returned.

            If the requested
            [Document][google.cloud.discoveryengine.v1beta.Document]
            does not exist, a NOT_FOUND error is returned.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListDocumentsRequest(proto.Message):
    r"""Request message for
    [DocumentService.ListDocuments][google.cloud.discoveryengine.v1beta.DocumentService.ListDocuments]
    method.

    Attributes:
        parent (str):
            Required. The parent branch resource name, such as
            ``projects/{project}/locations/{location}/collections/{collection}/dataStores/{data_store}/branches/{branch}``.
            Use ``default_branch`` as the branch ID, to list documents
            under the default branch.

            If the caller does not have permission to list
            [Documents][]s under this branch, regardless of whether or
            not this branch exists, a PERMISSION_DENIED error is
            returned.
        page_size (int):
            Maximum number of
            [Document][google.cloud.discoveryengine.v1beta.Document]s to
            return. If unspecified, defaults to 100. The maximum allowed
            value is 1000. Values above 1000 will be coerced to 1000.

            If this field is negative, an INVALID_ARGUMENT error is
            returned.
        page_token (str):
            A page token
            [ListDocumentsResponse.next_page_token][google.cloud.discoveryengine.v1beta.ListDocumentsResponse.next_page_token],
            received from a previous
            [DocumentService.ListDocuments][google.cloud.discoveryengine.v1beta.DocumentService.ListDocuments]
            call. Provide this to retrieve the subsequent page.

            When paginating, all other parameters provided to
            [DocumentService.ListDocuments][google.cloud.discoveryengine.v1beta.DocumentService.ListDocuments]
            must match the call that provided the page token. Otherwise,
            an INVALID_ARGUMENT error is returned.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListDocumentsResponse(proto.Message):
    r"""Response message for
    [DocumentService.ListDocuments][google.cloud.discoveryengine.v1beta.DocumentService.ListDocuments]
    method.

    Attributes:
        documents (MutableSequence[google.cloud.discoveryengine_v1beta.types.Document]):
            The
            [Document][google.cloud.discoveryengine.v1beta.Document]s.
        next_page_token (str):
            A token that can be sent as
            [ListDocumentsRequest.page_token][google.cloud.discoveryengine.v1beta.ListDocumentsRequest.page_token]
            to retrieve the next page. If this field is omitted, there
            are no subsequent pages.
    """

    @property
    def raw_page(self):
        return self

    documents: MutableSequence[gcd_document.Document] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=gcd_document.Document,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class CreateDocumentRequest(proto.Message):
    r"""Request message for
    [DocumentService.CreateDocument][google.cloud.discoveryengine.v1beta.DocumentService.CreateDocument]
    method.

    Attributes:
        parent (str):
            Required. The parent resource name, such as
            ``projects/{project}/locations/{location}/collections/{collection}/dataStores/{data_store}/branches/{branch}``.
        document (google.cloud.discoveryengine_v1beta.types.Document):
            Required. The
            [Document][google.cloud.discoveryengine.v1beta.Document] to
            create.
        document_id (str):
            Required. The ID to use for the
            [Document][google.cloud.discoveryengine.v1beta.Document],
            which will become the final component of the
            [Document.name][google.cloud.discoveryengine.v1beta.Document.name].

            If the caller does not have permission to create the
            [Document][google.cloud.discoveryengine.v1beta.Document],
            regardless of whether or not it exists, a PERMISSION_DENIED
            error is returned.

            This field must be unique among all
            [Document][google.cloud.discoveryengine.v1beta.Document]s
            with the same
            [parent][google.cloud.discoveryengine.v1beta.CreateDocumentRequest.parent].
            Otherwise, an ALREADY_EXISTS error is returned.

            This field must conform to
            `RFC-1034 <https://tools.ietf.org/html/rfc1034>`__ standard
            with a length limit of 63 characters. Otherwise, an
            INVALID_ARGUMENT error is returned.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    document: gcd_document.Document = proto.Field(
        proto.MESSAGE,
        number=2,
        message=gcd_document.Document,
    )
    document_id: str = proto.Field(
        proto.STRING,
        number=3,
    )


class UpdateDocumentRequest(proto.Message):
    r"""Request message for
    [DocumentService.UpdateDocument][google.cloud.discoveryengine.v1beta.DocumentService.UpdateDocument]
    method.

    Attributes:
        document (google.cloud.discoveryengine_v1beta.types.Document):
            Required. The document to update/create.

            If the caller does not have permission to update the
            [Document][google.cloud.discoveryengine.v1beta.Document],
            regardless of whether or not it exists, a PERMISSION_DENIED
            error is returned.

            If the
            [Document][google.cloud.discoveryengine.v1beta.Document] to
            update does not exist and
            [allow_missing][google.cloud.discoveryengine.v1beta.UpdateDocumentRequest.allow_missing]
            is not set, a NOT_FOUND error is returned.
        allow_missing (bool):
            If set to true, and the
            [Document][google.cloud.discoveryengine.v1beta.Document] is
            not found, a new
            [Document][google.cloud.discoveryengine.v1beta.Document]
            will be created.
    """

    document: gcd_document.Document = proto.Field(
        proto.MESSAGE,
        number=1,
        message=gcd_document.Document,
    )
    allow_missing: bool = proto.Field(
        proto.BOOL,
        number=2,
    )


class DeleteDocumentRequest(proto.Message):
    r"""Request message for
    [DocumentService.DeleteDocument][google.cloud.discoveryengine.v1beta.DocumentService.DeleteDocument]
    method.

    Attributes:
        name (str):
            Required. Full resource name of
            [Document][google.cloud.discoveryengine.v1beta.Document],
            such as
            ``projects/{project}/locations/{location}/collections/{collection}/dataStores/{data_store}/branches/{branch}/documents/{document}``.

            If the caller does not have permission to delete the
            [Document][google.cloud.discoveryengine.v1beta.Document],
            regardless of whether or not it exists, a PERMISSION_DENIED
            error is returned.

            If the
            [Document][google.cloud.discoveryengine.v1beta.Document] to
            delete does not exist, a NOT_FOUND error is returned.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.cloud.discoveryengine_v1beta.types import user_event as gcd_user_event

__protobuf__ = proto.module(
    package="google.cloud.discoveryengine.v1beta",
    manifest={
        "WriteUserEventRequest",
        "CollectUserEventRequest",
    },
)


class WriteUserEventRequest(proto.Message):
    r"""Request message for WriteUserEvent method.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        parent (str):
            Required. The parent DataStore resource name, such as
            ``projects/{project}/locations/{location}/collections/{collection}/dataStores/{data_store}``.
        user_event (google.cloud.discoveryengine_v1beta.types.UserEvent):
            Required. User event to write.

            This field is a member of `oneof`_ ``_user_event``.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    user_event: gcd_user_event.UserEvent = proto.Field(
        proto.MESSAGE,
        number=2,
        optional=True,
        message=gcd_user_event.UserEvent,
    )


class CollectUserEventRequest(proto.Message):
    r"""Request message for CollectUserEvent method.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        parent (str):
            Required. The parent DataStore resource name, such as
            ``projects/{project}/locations/{location}/collections/{collection}/dataStores/{data_store}``.
        user_event (str):
            Required. URL encoded UserEvent proto with a
            length limit of 2,000,000 characters.
        uri (str):
            The URL including cgi-parameters but
            excluding the hash fragment with a length limit
            of 5,000 characters. This is often more useful
            than the referer URL, because many browsers only
            send the domain for 3rd party requests.

            This field is a member of `oneof`_ ``_uri``.
        ets (int):
            The event timestamp in milliseconds. This
            prevents browser caching of otherwise identical
            get requests. The name is abbreviated to reduce
            the payload bytes.

            This field is a member of `oneof`_ ``_ets``.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    user_event: str = proto.Field(
        proto.STRING,
        number=2,
    )
    uri: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    ets: int = proto.Field(
        proto.INT64,
        number=4,
        optional=True,
    )


__all__ = tuple(sorted(__protobuf__.manifest))
